#[repr(C)]pub struct Checkpoint {
pub boost: Pubkey,
pub current_id: u64,
pub total_pending_deposits: u64,
pub total_stakers: u64,
pub total_rewards: u64,
pub ts: i64,
}Expand description
Checkpoint holds the checkpoint state of a particular boost.
Fields
boost: PubkeyThe boost this checkpoint is associated with.
current_id: u64The id of the next staker to be processed.
total_pending_deposits: u64The total amount of pending deposits in this checkpoint.
total_stakers: u64The number of total stakers in this checkpoint.
total_rewards: u64The total amount of rewards to distribute in this checkpoint.
ts: i64The timestamp of when the last checkpoint finished.
Implementations