#[repr(C)]pub struct Reservation {
pub authority: Pubkey,
pub boost: Pubkey,
pub noise: [u8; 32],
pub ts: i64,
}Expand description
Reservation tracks the current boost that a miner is allowed to use.
Fields
The proof account associated with this reservation.
boost: PubkeyThe boost this miner is allowed to use.
noise: [u8; 32]Random hash used to sample noise for the boost rotations.
ts: i64A timestamp to ensure only one rotation is executed per solution.
Implementations