#[repr(C)]pub struct Stake {
pub authority: Pubkey,
pub balance: u64,
pub balance_pending: u64,
pub boost: Pubkey,
pub id: u64,
pub last_deposit_at: i64,
pub rewards: u64,
}Expand description
Stake holds onto the deposits and yield of a boost staker.
Fields
The authority of this stake account.
balance: u64The balance of this stake account.
balance_pending: u64The amount of uncommitted stake in this account.
boost: PubkeyThe boost this stake account is associated with.
id: u64The id of this stake account.
last_deposit_at: i64The timestamp of the last time stake was added to this account.
rewards: u64The amount of rewards claimable by this staker.
Implementations